<?php
namespace Etn_Pro;

defined( 'ABSPATH' ) || exit;

use Etn_Pro\Core\Action;
use Etn_Pro\Core\Core;
use Etn_Pro\Core\Settings\Settings;
use Etn_Pro\Core\Woocommerce\Woocommerce_Deposit\Woocommerce_Deposit;
use Etn_Pro\Utils\Plugin_Installer;
use Etn\Utils\Helper;

final class Bootstrap {

	private static $instance;
	private $failed;

	public function __construct() {
		Autoloader::run();
	}

	public function package_type() {
		return 'pro';
	}

	public function product_id() {
		return '1013';
	}

	public function store_url() {
		return 'https://themewinter.com';
	}

	public function marketplace() {
		return 'themewinter';
	}

	public function author_name() {
		return 'themewinter';
	}

	public function account_url() {
		return 'https://account.themewinter.com';
	}

	public function api_url() {
		return 'https://api.themewinter.com/public/';
	}

	public static function instance() {

		if ( !self::$instance ) {
				self::$instance = new self();
		}

		return self::$instance;
	}

		/**
		 * Main function
		 *
		 * @return void
		 */
		public function init() {
		//make eventin free ready.
		$this->prepare_eventin();

		// check if eventin installed and activated
		if ( !did_action( 'eventin/after_load' ) ) {
				$this->failed = true;
		}

		if ( $this->failed == true ) {
				return;
		}

		//initialize license if only multisite is enabled and current site is main network site
		if (  ( !is_multisite() ) || ( is_multisite() && is_main_network() && is_main_site() && defined( 'MULTISITE' ) ) ) {
				$this->initialize_license_module();
		}

		include_once ABSPATH . 'wp-admin/includes/plugin.php';

		// fire up elementor widgets
		Widgets\Manifest::instance()->init();

		// fire up pro settings
		Settings::instance()->init();

		add_action( 'admin_enqueue_scripts', [$this, 'js_css_admin'] );
		add_action( 'wp_enqueue_scripts', [$this, 'js_css_public'] );
		add_action( 'elementor/frontend/before_enqueue_scripts', [$this, 'etn_elementor_js'] );
		// advanced search filter
		add_action( 'etn_advanced_search', '\Etn_Pro\Utils\Helper::advanced_search_filter' );

		//fire-up all woocommerce related hooks
		if ( file_exists( ETN_PRO_DIR . '/core/woocommerce/hooks.php' ) ) {
				include_once ETN_PRO_DIR . '/core/woocommerce/hooks.php';
		}
		
		// load sells engin.
		\Etn_Pro\Core\Modules\Sells_Engine\Sells_Engine::instance()->init();
		
		//  fire up all actions.
		\Etn_Pro\Core\Event\Event::instance()->init();
		
		// call shortcode hooks.
		\Etn_Pro\Core\Shortcodes\Hooks::instance()->init();
		
		// call speaker hooks.
		\Etn_Pro\Core\Metaboxs\Speaker_meta::instance()->init();
		
		// call event-metabox hooks.
		\Etn_Pro\Core\Metaboxs\Event_meta::instance()->init();
		
		// call event single-page view hook.
		\Etn_Pro\Core\Event\Single_Page_View::instance()->init();
		
		// Initialize event min-max qty module.
		\Etn_Pro\Core\Modules\Minmax\Minmax::instance()->init();

		if ( class_exists( 'Woocommerce' ) && class_exists( 'WeDevs_Dokan' ) && 0 !== get_current_user_id() ) {
			//Initialize event multi-vendor module.
			\Etn_Pro\Core\Modules\Multivendor\Multivendor::instance()->init();
		}
		if ( file_exists( ETN_PRO_DIR . "/core/speaker/views/template-hooks.php" ) ) {
				include_once ETN_PRO_DIR . "/core/speaker/views/template-hooks.php";
		}
		
		if ( file_exists( ETN_PRO_DIR . "/core/speaker/views/template-functions.php" ) ) {
				include_once ETN_PRO_DIR . "/core/speaker/views/template-functions.php";
		}

		Action::instance()->init();

		if ( class_exists( 'WC_Deposits' ) ) {
				Woocommerce_Deposit::instance()->init();
		}

				\Etn_Pro\Core\Attendee\Hooks::instance()->init();

		// fire up all migrations.
		\Etn_Pro\Core\Migration\Migration::instance()->init();

		// call ajax submit.
		if ( defined( 'DOING_AJAX' ) && DOING_AJAX ) {
			// All ajax action.
			\Etn_Pro\Widgets\Event_Locations\Actions\Ajax_Action::instance()->init();
		}

		}

		public function initialize_license_module() {

				if ( current_user_can( 'manage_etn_settings' ) && current_user_can( 'manage_options' ) ) {

						//add submenu for license
						add_action( "admin_menu", [$this, "add_submenu_for_license"], 102 );

						//handle license notice
						$this->manage_license_notice();

						//fire up edd update module
						Utils\Updater\Init::instance()->init();
				}

		}

		/**
		 * Add admin submenu page for license
		 */
		public function add_submenu_for_license() {
				//add submenu page for go-pro
				add_submenu_page(
						'etn-events-manager',
						__( 'License', 'eventin-pro' ),
						__( 'License', 'eventin-pro' ),
						'manage_options',
						'etn-license',
						[$this, 'etn_license_page']
				);
		}

		public function etn_license_page() {
				$file_path = plugin_dir_path( __FILE__ ) . "/core/settings/views/license-settings-view.php";

				if ( file_exists( $file_path ) ) {
						include_once $file_path;
				}

		}

		public function manage_license_notice() {
				$license_settings = \Etn_Pro\Utils\Helper::get_option( "license" );
				$enable_license   = ( !empty( $license_settings ) ? true : false );

				// Register license module
				$license = \Etn_Pro\Utils\License\License::instance();

				//fire up edd license module
				$license->init();

				$settings              = get_option( "etn_premium_marketplace" );
				$selected_market_place = empty( $settings ) ? "" : $settings;

				if ( !$enable_license || $selected_market_place == "codecanyon" ) {
						return;
				}

				if ( $license->status() != 'valid' ) {
						\Oxaim\Libs\Notice::instance( 'eventin-pro', 'pro-not-active' )
								->set_class( 'error' )
								->set_dismiss( 'global', ( 3600 * 24 * 7 ) )
								->set_message( esc_html__( 'Please activate Eventin Pro to get automatic updates and premium support.', 'eventin-pro' ) )
								->set_button( [
										'url'   => self_admin_url( 'admin.php?page=etn-license' ),
										'text'  => 'Activate License Now',
										'class' => 'button-primary',
								] )
								->call();
				}

		}

		/**
		 * Prepare wp-cafe free version if not activated
		 *
		 * @return void
		 */
		private function prepare_eventin() {

				// if eventin not installed
				if ( !did_action( 'eventin/after_load' ) ) {

						if ( Plugin_Installer::instance()->make_eventin_ready() ) {
								// redirect to plugin dashboard
								wp_safe_redirect( "admin.php?page=etn-event-settings" );
						}

				}

		}

		public function js_css_public() {

				wp_enqueue_style( 'swiper-bundle-min', ETN_PRO_ASSETS . 'css/swiper-bundle.min.css', [], \Wpeventin_Pro::version(), 'all' );
				wp_enqueue_style( 'jquery-countdown', ETN_PRO_ASSETS . 'css/jquery.countdown.css', [], \Wpeventin_Pro::version(), 'all' );
				wp_enqueue_style( 'etn-custom', ETN_PRO_ASSETS . 'css/custom.css', [], \Wpeventin_Pro::version(), 'all' );
				wp_enqueue_style( 'etn-public', ETN_PRO_ASSETS . 'css/etn-public.css', [], \Wpeventin_Pro::version(), 'all' );

				if ( is_rtl() ) {
						wp_enqueue_style( 'etn-rtl-pro', ETN_PRO_ASSETS . 'css/rtl.css' );
				}

				wp_enqueue_script( 'swiper-bundle-min', ETN_PRO_ASSETS . 'js/swiper-bundle.min.js', ['jquery'], \Wpeventin_Pro::version(), false );
				wp_enqueue_script( 'jquery-countdown', ETN_PRO_ASSETS . 'js/jquery.countdown.min.js', ['jquery'], \Wpeventin_Pro::version(), false );
				wp_enqueue_script( 'etn-qr-code', ETN_PRO_ASSETS . 'js/qr-code.js', array( 'jquery' ), '4.0.10', false );
				wp_enqueue_script( 'etn-qr-code-scanner', ETN_PRO_ASSETS . 'js/qr-scanner.umd.min.js', array( 'jquery' ), '4.0.10', false );
				wp_enqueue_script( 'etn-qr-code-custom', ETN_PRO_ASSETS . 'js/qr-code-custom.js', array( 'jquery' ), '4.0.10', false );
				wp_enqueue_script( 'etn-public-pro', ETN_PRO_ASSETS . 'js/etn-public.js', ['jquery', 'etn-qr-code'], \Wpeventin_Pro::version(), false );

				
				// event location js start.
				$settings = get_option("etn_event_options");
				if ( ! empty( $settings['etn_googlemap_api'] ) ) {
					$map_js   = $this->map_url();
					wp_enqueue_script( 'etn-map', $map_js , array( 'jquery' ), '4.0.10', false );
					wp_enqueue_script( 'etn-location', ETN_PRO_ASSETS . 'js/etn-location.js', array( 'jquery' ), '4.0.10', false );
				}
				// event location js end.
				$settings            = Helper::get_settings();
				$attendee_verification_style =  isset( $settings["attendee_verification_style"] ) ? $settings["attendee_verification_style"] : 'on';
				$attendee_registration =  !empty( $settings["attendee_registration"] ) ? true : false;

				$array      = [
						'ajax_url'                      => admin_url( 'admin-ajax.php' ),
						'location_map_nonce'            => wp_create_nonce( 'location_map_nonce' ),
						'scanner_nonce'                 => wp_create_nonce( 'scanner_nonce_value' ),
						'attendee_page_link'            => admin_url('/edit.php?post_type=etn-attendee'),
						'scanner_common_msg'            => esc_html__( 'Something went wrong! Please try again.', 'eventin-pro' ),
						'attendee_verification_style'   => $attendee_verification_style,
						'location_icon'                 => \Wpeventin_Pro::assets_url() . 'images/location-icon.png',
						'attendee_registration_option'  => $attendee_registration,
				];

				wp_localize_script( 'etn-public-pro', 'etn_pro_public_object', $array );

				if ( class_exists( 'Woocommerce' ) && class_exists( 'WeDevs_Dokan' ) && 0 !== get_current_user_id() ) {
					wp_enqueue_style( 'etn-multivendor', \Wpeventin_Pro::plugin_url() . 'multivendor/build/index.css', [ ], \Wpeventin_Pro::version(), 'all' );
					wp_enqueue_script( 'etn-multivendor', \Wpeventin_Pro::plugin_url() . 'multivendor/build/index.js', [ 'wp-i18n'], \Wpeventin_Pro::version(), true );
				}
		}

		/**
		* Get Map Url
		*/
		public function map_url() {
		$map_js   = 'https://maps.google.com/maps/api/js?libraries=places';
		$settings = get_option("etn_event_options");
		if ( ! empty( $settings ) ) {
				$api_key = !empty( $settings['google_api_key'] ) ? $settings['google_api_key'] : 'AIzaSyBRiJpfKRV-hDFuQ6ynEAStJVO09g5Ecd4';
				$map_js  = $map_js . '&key=' . $api_key;
		}

		return $map_js;
	}

	public function js_css_admin() {

		// get screen id
		$screen    = get_current_screen();
		$screen_id = $screen->id;		
		$allowed_screen_ids = array(
			'post',
			'page',
			'etn',
			'edit-etn',
			'etn-attendee',
			'edit-etn-attendee',
			'edit-etn_category',
			'edit-etn_tags',
			'etn-schedule',
			'edit-etn-schedule',
			'edit-etn_speaker_category',
			'etn-speaker',
			'edit-etn-speaker',
			'etn-zoom-meeting',
			'edit-etn-zoom-meeting',
			'eventin_page_etn-event-settings',
			'eventin_page_etn_sales_report',
			'eventin_page_eventin_get_help',
			'eventin_page_etn-license',
			'edit-etn_location',
			'eventin_page_etn_stripe_orders_report',
		);

		if ( in_array( $screen_id, $allowed_screen_ids ) ) {
				wp_enqueue_style( 'etn-admin', ETN_PRO_ASSETS . 'css/etn-admin.css', [], \Wpeventin_Pro::version(), 'all' );
				wp_enqueue_script( 'etn-admin-pro', ETN_PRO_ASSETS . 'js/etn-admin.js', ['jquery', 'wp-color-picker'], \Wpeventin_Pro::version(), false );

				// Event location js start.
				wp_enqueue_script( 'etn-pro-map-admin', $this->map_url(), ['jquery'], \Wpeventin_Pro::version(), true );
				wp_enqueue_script( 'etn-location-admin', ETN_PRO_ASSETS . 'js/etn-location-admin.js', ['jquery'], \Wpeventin_Pro::version(), false );
				// Event location js end.

				$base_url               = admin_url( );
				$attendee_cpt           = new \Etn\Core\Attendee\Cpt();
				$attendee_endpoint      = $attendee_cpt->get_name();
				$action_url             = $base_url . $attendee_endpoint;
				$ticket_scanner_link    = $action_url . "&etn_action=". urlencode('ticket_scanner'); 
				$ticket_scanner_link    = admin_url('/edit.php?post_type=etn-attendee&etn_action=ticket_scanner');

				// localize data
				$license_settings = \Etn_Pro\Utils\Helper::get_option( "license" );
				$enable_license   = ( !empty( $license_settings ) ? "yes" : "no" );
				$array            = [
						'ajax_url'              => admin_url( 'admin-ajax.php' ),
						'license_module'        => $enable_license,
						'scanner_nonce'         => wp_create_nonce( 'scanner_nonce_value' ),
						'ticket_scanner_link'   => $ticket_scanner_link,
						'ticket_scanner_text'   => esc_html__('Ticket Scanner', 'eventin-pro'),
						'required'              => esc_html__('Required','eventin-pro'),
						'optional'              => esc_html__('Optional','eventin-pro'),
						'warning_message'       => esc_html__('Please fill the label field','eventin-pro'),
						'warning_icon'          => '<svg width="17" height="17" viewBox="0 0 17 17" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M13.6574 2.34456C10.5339 -0.778916 5.46609 -0.778916 2.34261 2.34456C-0.78087 5.46804 -0.78087 10.5359 2.34261 13.6593C5.46609 16.7828 10.5339 16.7828 13.6574 13.6593C16.7843 10.5324 16.7809 5.46804 13.6574 2.34456ZM9.04522 11.4785C9.04522 12.0559 8.57913 12.522 8.00174 12.522C7.42435 12.522 6.95826 12.0559 6.95826 11.4785V7.30456C6.95826 6.72717 7.42435 6.26108 8.00174 6.26108C8.57913 6.26108 9.04522 6.72717 9.04522 7.30456V11.4785ZM7.98435 5.52021C7.38261 5.52021 6.98261 5.09587 6.99652 4.57065C6.98261 4.02108 7.38609 3.60717 7.99826 3.60717C8.61044 3.60717 9 4.02108 9.01391 4.57065C9.01044 5.09587 8.61044 5.52021 7.98435 5.52021Z" fill="#F42929"/></svg>',
				];

				wp_localize_script( 'etn-admin-pro', 'etn_pro_admin_object', $array );
		}

	}

	public function etn_elementor_js() {
			wp_enqueue_script( 'etn-elementor-pro-inputs', ETN_PRO_ASSETS . 'js/elementor.js', ['elementor-frontend'], \Wpeventin_Pro::version(), true );
	}

}
