<?php

namespace Etn_Pro\Core\Attendee;
use \Etn_Pro\Utils\Helper;

defined( 'ABSPATH' ) || exit;
/**
 * Attendee functionalities
 */
class Hooks {
	use \Etn_Pro\Traits\Singleton;
	/**
	 * Fire all hooks
	 */
	public function init() {
		// filter attendee with event name.
		add_action( 'restrict_manage_posts', [$this, 'show_attendee_report_filter'] );
		add_filter( 'parse_query', [$this, 'attendee_report_filter_result'] );

		// add bulk action to update attendee post status
		add_filter( 'bulk_actions-edit-etn-attendee', [$this, 'attendee_bulk_action_change_status_to_publish'] );
		add_filter( 'handle_bulk_actions-edit-etn-attendee', [$this, 'attendee_bulk_action_change_to_publish'], 10, 3 );
		add_action( 'admin_notices', [$this, 'attendee_show_notice_after_change_to_publish'] );

		// add bulk action to download attendee details as csv
		add_filter( 'bulk_actions-edit-etn-attendee', [$this, 'attendee_bulk_action_download_csv'] );
		add_filter( 'handle_bulk_actions-edit-etn-attendee', [$this, 'attendee_handle_bulk_action_download_csv'], 10, 3 );
		add_action( 'admin_notices', [$this, 'attendee_show_notice_after_download_csv'] );

		add_filter( 'etn_attendee_fields', [$this, 'etn_attendee_fields_add_extra'] );

		add_action( 'etn\pdf\before_main_details', [$this, 'before_pdf_body_show_unique_id'], 10, 3 );

        add_filter( 'posts_join', [ $this, 'attendee_ticket_id_search_join' ] );
        
        add_filter( 'posts_where', [ $this, 'attendee_ticket_id_search_where' ] );

        add_filter( "manage_etn-attendee_posts_columns", [$this, "attendee_post_columns"], 10, 1 );
        add_action( "manage_etn-attendee_posts_custom_column", [$this, 'attendee_custom_column_data'], 10, 2 );

        add_action( 'init', [$this, 'scanner_module_functionalities'] );
        add_action( "etn_pro_ticket_qr", [$this, 'etn_pro_ticket_qr_cb'], 10, 2 );
        add_action( "etn_pro_ticket_id", [$this, 'etn_pro_ticket_id_cb'], 10, 2 );
    }

	/**
	 * Dashboard column positioning
	 */
	public function attendee_post_columns( $columns ) {
 
		$settings = \Etn\Core\Settings\Settings::instance()->get_settings_option();

		$attendee_extra_fields = isset( $settings['attendee_extra_fields']) ? $settings['attendee_extra_fields'] : [];

		$extra_items = array();
		if( is_array($attendee_extra_fields) && !empty($attendee_extra_fields) ){
			foreach( $attendee_extra_fields as $index => $attendee_extra_field ){

				if( isset($attendee_extra_field['show_in_dashboard']) && $attendee_extra_field['label'] != '' ){
					$column_name = Helper::generate_name_from_label("etn_attendee_extra_field_", $attendee_extra_field['label']);
					$extra_items[ $column_name ] = esc_html__( $attendee_extra_field['label'], 'eventin-pro' );
				}

			}
		}
 
		$new_item['unique_id'] = esc_html__( 'Ticket ID', 'eventin-pro' );
 
        $slice_pos = 2;
        if( !empty(Helper::get_option('reg_require_email')) ){
            $slice_pos += 1;
        }

        if( !empty(Helper::get_option('reg_require_phone')) ){
            $slice_pos += 1;
        }

        $new_columns = array_slice( $columns, 0, 1, true ) + $new_item + 
            array_slice( $columns, 1, $slice_pos, true ) + $extra_items +
            array_slice( $columns, 3, count( $columns ) - 1, true );

        return $new_columns;

    }

    /**
     * Return row
     */
	public function attendee_custom_column_data( $column, $post_id ){
		$ticket_id   = '#' . get_post_meta( $post_id, 'etn_unique_ticket_id', true );

		switch ( $column ){
			case 'unique_id':
				echo esc_html( $ticket_id );
				break;
		}

		$settings = \Etn\Core\Settings\Settings::instance()->get_settings_option();
		$attendee_extra_fields = isset($settings['attendee_extra_fields']) ? $settings['attendee_extra_fields'] : [];

		if( is_array($attendee_extra_fields) && !empty($attendee_extra_fields) ){
			foreach( $attendee_extra_fields as $index => $attendee_extra_field ){

				if( $attendee_extra_field['label'] != '' ){
					$column_name = Helper::generate_name_from_label("etn_attendee_extra_field_", $attendee_extra_field['label']);	
					
					if( $column == $column_name ){
						if( $attendee_extra_field['type'] == 'radio' ) {
							$radio_val = get_post_meta( $post_id, $column_name, true );
							if( isset( $attendee_extra_field['radio'] ) ){
								if( is_array( $attendee_extra_field['radio'] ) && !empty( $attendee_extra_field['radio'] ) ){
									if( isset( $attendee_extra_field['radio'][$radio_val] ) ){
										echo esc_html__( $attendee_extra_field['radio'][$radio_val], 'eventin-pro' ); 
									}
								}
							}
						}
						else if( $attendee_extra_field['type'] == 'checkbox' ) {
							$checkbox_serialized_arr = maybe_unserialize( get_post_meta( $post_id, $column_name, true ) );
													
							if( isset( $attendee_extra_field['checkbox'] ) ){
								if( is_array( $attendee_extra_field['checkbox'] ) && !empty( $attendee_extra_field['checkbox'] ) ){
									if( is_array( $checkbox_serialized_arr ) && !empty( $checkbox_serialized_arr ) ){
										$checkbox_text_arr = [];
										foreach( $checkbox_serialized_arr as $index => $val ){
											if( isset( $attendee_extra_field['checkbox'][$val] ) ){
												array_push( $checkbox_text_arr, esc_html__( $attendee_extra_field['checkbox'][$val], 'eventin-pro' ) );
											}
										}

										echo join( ', ', $checkbox_text_arr );
									}
								}
							}
						} else {
							echo esc_html( get_post_meta( $post_id, $column_name, true ) );
						}
						break;
					}
				}

			}
		}
		
	}


    /**
     * Join postmeta in admin post search
     *
     * @return string SQL join
     */
    function attendee_ticket_id_search_join( $join ){
        global $pagenow, $wpdb;
        if ( is_admin() && $pagenow == 'edit.php' && ! empty( $_GET['post_type'] ) && $_GET['post_type'] == 'etn-attendee' && ! empty( $_GET['s'] ) ) {
            $join .= 'LEFT JOIN ' . $wpdb->postmeta . ' AS etn_meta_table  ON ' . $wpdb->posts . '.ID = etn_meta_table.post_id ';
        }
        return $join;
    }

    /**
     * Filtering the where clause in admin post search query
     *
     * @return string SQL WHERE
     */
    function attendee_ticket_id_search_where( $where ){
        global $pagenow, $wpdb;
        if ( is_admin() && $pagenow == 'edit.php' && ! empty( $_GET['post_type'] ) && $_GET['post_type'] == 'etn-attendee' && ! empty( $_GET['s'] ) ) {
            $where = preg_replace( "/\(\s*" . $wpdb->posts . ".post_title\s+LIKE\s*(\'[^\']+\')\s*\)/", "(" . $wpdb->posts . ".post_title LIKE $1) OR ( etn_meta_table.meta_value LIKE $1)", $where );
        }
        return $where;
    }

    /**
     * Add extra fields to attendee cpt metabox
     *
     * @param [type] $default_attendee_fields
     * @return void
     */
	public function etn_attendee_fields_add_extra( $default_attendee_fields ){
		$settings              = Helper::get_settings();
		$attendee_extra_fields = isset($settings['attendee_extra_fields']) ? $settings['attendee_extra_fields'] : [];

		if ( is_array($attendee_extra_fields) && !empty($attendee_extra_fields) ){
			foreach( $attendee_extra_fields as $index => $attendee_extra_field ){

				$label_content = $attendee_extra_field['label'];

				if( $label_content != '' ){
					$extra_field_label = $label_content;
					$extra_field_name  = Helper::generate_name_from_label("etn_attendee_extra_field_", $label_content);
					$extra_field_desc  = $attendee_extra_field['place_holder'];
					$extra_field_type  = $attendee_extra_field['type'] == "checkbox" ? "multi_checkbox" : $attendee_extra_field['type'];
					
					$default_attendee_fields[$extra_field_name] = [
						'label' => esc_html( $extra_field_label ),
						'type'  => $extra_field_type,
						'value' => '',
						'desc'  => $extra_field_desc,
						'attr'  => ['class' => 'etn-label-item'],
						'group' => 'etn-label-group',
                        'tooltip_title' => '',
                        'tooltip_desc' =>  ''
					];

					if ( $extra_field_type == "multi_checkbox" ) {
						$default_attendee_fields[$extra_field_name]['inputs'] = $attendee_extra_field['checkbox'];
						$default_attendee_fields[$extra_field_name]['input_checked'] = $attendee_extra_field['checkbox'];
					}
					
					if( $extra_field_type == 'radio' ){
						$radio_options = ( isset( $attendee_extra_field['radio'] ) && is_array( $attendee_extra_field['radio'] ) ) ? $attendee_extra_field['radio'] :  [];
						$default_attendee_fields[$extra_field_name]['options'] = $radio_options;
					}
		
					if( $extra_field_type == 'checkbox' ){
						$checkbox_options = ( isset( $attendee_extra_field['checkbox'] ) && is_array( $attendee_extra_field['checkbox'] ) ) ? $attendee_extra_field['checkbox'] :  [];
						$default_attendee_fields[$extra_field_name]['options'] = $checkbox_options;
					}
				}
				
			}
		}

		$default_attendee_fields['etn_unique_ticket_id']   = [
			'label'    => esc_html__( 'Ticket ID', 'eventin-pro' ),
			'desc'     => esc_html__( 'Ticket ID will be generated automatically after purchasing ticket successfully', 'eventin-pro' ),
			'type'     => 'text',
			'value'    => "",
			'priority' => 1,
			'readonly' => true,
			'disabled' => true,
			'placeholder'     => esc_html__( 'Ticket ID', 'eventin-pro' ),
			'attr'     => ['class' => 'etn-label-item'],
			'group'    => 'etn-label-group',
            'tooltip_title' => '',
                'tooltip_desc' =>  ''
		];

		$default_attendee_fields['ticket_name']   = [
			'label'    => esc_html__( 'Ticket Name', 'eventin-pro' ),
			'desc'     => esc_html__( 'Ticket Name which client have been purchased', 'eventin-pro' ),
			'type'     => 'text',
			'value'    => ETN_DEFAULT_TICKET_NAME,
			'priority' => 1,
			'readonly' => true,
			'disabled' => true,
			'placeholder'     => esc_html__( 'Ticket Name', 'eventin-pro' ),
			'attr'     => ['class' => 'etn-label-item'],
			'group'    => 'etn-label-group',
            'tooltip_title' => '',
            'tooltip_desc' =>  ''
		];
	
		return $default_attendee_fields;
	}


    /**
     * Update query
     * @since 1.1.0
     * @return void
     */
    function attendee_report_filter_result( $query ) {

        if (!(is_admin()) && $query->is_main_query()) {
            return $query;
        }
        
        $event_id       = isset($_GET['event_id']) && $_GET['event_id'] !=="" ? sanitize_text_field($_GET['event_id']) : null;
        $etn_status     = isset($_GET['etn_status']) && $_GET['etn_status'] !=="" ? sanitize_text_field($_GET['etn_status']) : null;
        $etn_attendeee_status = isset($_GET['etn_attendeee_ticket_status']) && $_GET['etn_attendeee_ticket_status'] !=="" ? sanitize_text_field($_GET['etn_attendeee_ticket_status']) : null;

        if ( !isset($query->query['post_type']) || ('etn-attendee' !== $query->query['post_type'])  || ( !isset( $event_id ) && !isset( $etn_status ) && !isset( $etn_attendeee_status ) ) ) {
            return $query;
        }
        
        $relation = []; $meta_etn_status = []; $meta_attendeee_status=[]; $meta_event_name =[];

        if ( isset( $event_id ) && ( isset( $etn_status ) || isset( $etn_attendeee_status ) ) ) {
            $relation = ['relation' => 'OR'];

            if ( isset( $etn_status ) ) {
                $meta_etn_status = array(
                    'key'       =>   'etn_status',
                    'value'     =>  $etn_status ,
                    'compare'   => "=",
                );
            }
            if ( isset( $etn_attendeee_status ) ) {
                $meta_attendeee_status = array(
                    'key'       =>   'etn_attendeee_ticket_status',
                    'value'     =>  $etn_attendeee_status ,
                    'compare'   => "=",
                );
            }
        }
        if ( empty( $event_id ) &&  empty( $etn_status ) && !empty( $etn_attendeee_status )  ) {
            $meta_attendeee_status = array(
                'key'       => 'etn_attendeee_ticket_status',
                'value'     =>  $etn_attendeee_status ,
                'compare'   => "=",
            );
        }
        
        if ( isset( $etn_status ) && !isset( $event_id )  && !isset( $etn_attendeee_status )  ) {
            $meta_etn_status = array(
                'key'       => 'etn_status',
                'value'     =>  $etn_status ,
                'compare'   => "LIKE",
            );
        }

        if ( isset( $event_id ) ) {
            // setup this functions meta values
            $meta_event_name = array(
                'key'       =>  'etn_event_id',
                'value'     =>  $event_id ,
                'compare'   => "=",
            );
        }
        
        if (!isset($query->query_vars['meta_query'])) {
            
            $query->query_vars['meta_query'] = array();
            if ( count( $relation )>0 ) {
                $query->query_vars['meta_query'] = array( $relation );
            }

            // append to meta_query array
            if ( count( $meta_event_name )> 0 ) {
                $query->query_vars['meta_query'][] = $meta_event_name;
            }

            if ( count( $meta_etn_status )> 0 ) {
                $query->query_vars['meta_query'][] = $meta_etn_status;
            }

            if ( count( $meta_attendeee_status )> 0 ) {
                $query->query_vars['meta_query'][] = $meta_attendeee_status;
            }

        }
        return $query;
    }

    /**
     * Filter slugs
     * @since 1.1.0
     * @return void
     */
    function show_attendee_report_filter() {
        global $typenow;

        if ( $typenow == 'etn-attendee' ) {
            //Filter by event
            $all_events = get_posts( [ 
                'post_type' => 'etn', 
                'numberposts' => '-1', 
                'suppress_filters' => false, 
            ] );
            
            $events = [];

            foreach ( $all_events as $key => $value ) {
                $id          = $value->ID;
                $title       = $value->post_title;
                $events[$id] = $title;
            }

            $current_event_name = '';

            if ( isset( $_GET['event_id'] ) ) {
                $current_event_name = sanitize_text_field( $_GET['event_id'] ); // Check if option has been selected
            }
            ?>

            <select name="event_id" id="event_id">
                <option value="" <?php selected( 'all_events', $current_event_name );?>>
                    <?php echo esc_html__( 'All Events', 'eventin-pro' ); ?>
                </option>
                <?php
                foreach ( $events as $key => $value ) {
                    ?>
                    <option value="<?php echo esc_attr( $key ); ?>" <?php selected( $key, $current_event_name );?>>
                        <?php echo esc_attr( $value ); ?>
                    </option>
                    <?php
                }
                ?>
            </select>

            <?php
            // Payment status
            $all_status = [
                'success' => esc_html__('Success', 'eventin-pro'),
                'failed'  => esc_html__('Failed', 'eventin-pro'),
            ];

            $current_status = '';

            if ( isset( $_GET['etn_status'] ) ) {
                $current_status = sanitize_text_field( $_GET['etn_status'] );
            }

            ?>

            <select name='etn_status' id='etn_status'>
                <option value='' <?php selected( 'etn_status', $current_status );?>><?php echo esc_html__( 'All Payment Status', 'eventin-pro' ); ?></option>
                <?php
                    foreach ( $all_status as $key => $value ) {
                        ?>
                        <option value="<?php echo esc_attr( $key ); ?>" <?php selected( $key, $current_status ); ?>><?php echo esc_html( $value ); ?></option>
                        <?php
                    }
                ?>
            </select>

            <?php
            // Ticket using status
            $all_status = [
                'unused' => esc_html__( 'Unused', 'eventin-pro' ),
                'used'   => esc_html__( 'Used', 'eventin-pro' ),
            ];

            $current_ticket_status = '';

            if ( isset( $_GET['etn_attendeee_ticket_status'] ) ) {
                $current_ticket_status = sanitize_text_field( $_GET['etn_attendeee_ticket_status'] );
            }

            ?>

            <select name="etn_attendeee_ticket_status" id="etn_attendeee_ticket_status">
                <option value="" <?php selected( 'all_ticket', $current_ticket_status );?>>
                    <?php echo esc_html__( 'All Ticket Status', 'eventin-pro' ); ?>
                </option>
                <?php
                foreach ( $all_status as $key => $value ) {
                    ?>
                    <option value="<?php echo esc_attr( $key ); ?>" <?php selected( $key, $current_ticket_status );?>>
                        <?php echo esc_attr( $value ); ?>
                    </option>
                    <?php
                }
                ?>
            </select>

            <?php
        }

    }
    
    /**
     * Show notice after post status changed to published
     *
     * @return void
     */
    function attendee_show_notice_after_change_to_publish() {

        if ( !empty( $_REQUEST['changed-to-published'] ) ) {
            $num_changed = (int) $_REQUEST['changed-to-published'];
            printf( '<div id="message" class="updated notice is-dismissable"><p>' . __( 'Published %d posts.', 'eventin-pro' ) . '</p></div>', $num_changed );
        }

    }

    /**
     * Change multiple post status to Publish
     *
     * @param [type] $redirect_url
     * @param [type] $action
     * @param [type] $post_ids
     * @return void
     */
    function attendee_bulk_action_change_to_publish( $redirect_url, $action, $post_ids ) {

        if ( $action == 'change-to-published' ) {

            foreach ( $post_ids as $post_id ) {
                wp_update_post( [
                    'ID'          => $post_id,
                    'post_status' => 'publish',
                ] );
            }

            $redirect_url = add_query_arg( 'changed-to-published', count( $post_ids ), $redirect_url );
        }

        return $redirect_url;
    }

    /**
     * add custom bulk action to attendee dashboard
     *
     * @param [type] $bulk_actions
     * @return void
     */
    public function attendee_bulk_action_change_status_to_publish( $bulk_actions ) {
        $bulk_actions['change-to-published'] = esc_html__( 'Change to published', 'eventin-pro' );
        return $bulk_actions;
    }



    /**
     * add custom bulk action to attendee dashboard
     *
     * @param [type] $bulk_actions
     * @return void
     */
    public function attendee_bulk_action_download_csv( $bulk_actions ) {
        $bulk_actions['download-attendee-csv'] = esc_html__( 'Download Details as CSV', 'eventin-pro' );
        return $bulk_actions;
    }

    /**
     * Undocumented function
     *
     * @param [type] $redirect_url
     * @param [type] $action
     * @param [type] $post_ids
     * @return void
     */
	function attendee_handle_bulk_action_download_csv( $redirect_url, $action, $post_ids ) {

		if ( $action == 'download-attendee-csv' ) {

			$settings              = \Etn\Core\Settings\Settings::instance()->get_settings_option();
			$attendee_extra_fields = isset($settings['attendee_extra_fields']) ? $settings['attendee_extra_fields'] : [];

			$extra_field_array = [];

			if( is_array( $attendee_extra_fields ) && !empty( $attendee_extra_fields ) ){
				foreach( $attendee_extra_fields as $attendee_extra_field ){

					$label_content = $attendee_extra_field['label'];
					if( $label_content != '' ){
						$extra_field_type = $attendee_extra_field['type'];
						$name_from_label['label'] = $label_content;
						$name_from_label['type']  = $extra_field_type;

						if ( $extra_field_type == 'radio' ) {
							$name_from_label['type_radio_arr'] = isset( $attendee_extra_field['radio'] ) ? $attendee_extra_field['radio'] : []; // rel 2.5
						}
						else if ( $extra_field_type == 'checkbox' ) {
							$name_from_label['type_checkbox_arr'] = isset( $attendee_extra_field['checkbox'] ) ? $attendee_extra_field['checkbox'] : []; // rel 2.5
						}

						$name_from_label['name']  = \Etn_Pro\Utils\Helper::generate_name_from_label("etn_attendee_extra_field_", $label_content);
						array_push( $extra_field_array, $name_from_label );
					}
				}

			}

			$attendee_array =  [];
			foreach ( $post_ids as $post_id ) {
				//create attendee array
				$attendee_array[$post_id]['etn_name'] = get_the_title( $post_id );

				if( !empty(Helper::get_option('reg_require_email')) ){
					$attendee_array[$post_id]['etn_email']      =  get_post_meta( $post_id, 'etn_email', true );
				}
				
				if( !empty(Helper::get_option('reg_require_phone')) ){
					$attendee_array[$post_id]['etn_phone']      =  get_post_meta( $post_id, 'etn_phone', true );
				}

				$attendee_array[$post_id]['ticket_id']      =  '#' . get_post_meta( $post_id, 'etn_unique_ticket_id', true );
				$attendee_array[$post_id]['ticket_name']    =  !empty( get_post_meta( $post_id, 'ticket_name', true ) ) ? get_post_meta( $post_id, 'ticket_name', true ) : ETN_DEFAULT_TICKET_NAME;
				$attendee_array[$post_id]['event_name']     =  get_the_title( get_post_meta( $post_id, 'etn_event_id', true ) );
				$attendee_array[$post_id]['payment_status'] =  get_post_meta( $post_id, 'etn_status', true );
				$attendee_array[$post_id]['ticket_status']  =  get_post_meta( $post_id, 'etn_attendeee_ticket_status', true );
				
			}

			$this->download_attendee_information_csv( $attendee_array, $extra_field_array );

			$redirect_url = add_query_arg( 'download-attendee-csv', count( $post_ids ), $redirect_url );
		}

		return $redirect_url;
	}

    /**
     * Undocumented function
     *
     * @return void
     */
    function attendee_show_notice_after_download_csv() {

        if ( !empty( $_REQUEST['download-attendee-csv'] ) ) {
            $num_downloaded = (int) $_REQUEST['download-attendee-csv'];
            printf( '<div id="message" class="updated notice is-dismissable"><p>' . esc_html__( 'Downloaded %d attendee information.', 'eventin-pro' ) . '</p></div>', $num_downloaded );
        }

    }

    /**
     * Export CSV file with selected attendees
     *
     * @param [type] $attendee_array
     * @return void
     */
	public function download_attendee_information_csv( $attendee_array, $extra_field_array ) {

		$generated_date = date( 'd-m-Y His' ); //Date will be part of file name.
		$table_title_array[] = esc_html__('Id', 'eventin-pro');
		$table_title_array[] = esc_html__('Name', 'eventin-pro');
		if( !empty(Helper::get_option('reg_require_email')) ){
			$table_title_array[] = esc_html__('Email', 'eventin-pro');
		}
		if( !empty(Helper::get_option('reg_require_phone')) ){
			$table_title_array[] = esc_html__('Phone', 'eventin-pro');
		}
		$table_title_array[] = esc_html__('Event Name', 'eventin-pro');
		$table_title_array[] = esc_html__('Payment Status', 'eventin-pro');
		$table_title_array[] = esc_html__('Ticket Status', 'eventin-pro');
		$table_title_array[] = esc_html__('Ticket ID', 'eventin-pro');
		$table_title_array[] = esc_html__('Ticket Name', 'eventin-pro');

		//add extra fields label to csv file header row 
		foreach( $extra_field_array as $extra_field ){
			array_push( $table_title_array, $extra_field['label'] );
		}



		header( "Content-type: text/csv" );
		header( "Content-Disposition: attachment; filename=\"etn_attendee_info_" . $generated_date . ".csv\";" );
		ob_end_clean();

		// create a file pointer connected to the output stream
		$output = fopen( 'php://output', 'w' ) or die( "Can\'t open php://output" );

		// output the column headings
		fputcsv(
			$output,
			$table_title_array
		);
		
		foreach ( $attendee_array as $key => $value ) {
			$table_content_row = [];
			array_push( $table_content_row, $key );
			array_push( $table_content_row, $value['etn_name'] );
			if( !empty(Helper::get_option('reg_require_email')) ){
				array_push( $table_content_row, $value['etn_email'] );
			}
			if( !empty(Helper::get_option('reg_require_phone')) ){
				array_push( $table_content_row, "=\"" . $value['etn_phone'] . "\"" );
			}
			array_push( $table_content_row, $value['event_name'] );
			array_push( $table_content_row, $value['payment_status'] );
			array_push( $table_content_row, $value['ticket_status'] );
			array_push( $table_content_row, $value['ticket_id'] );
			array_push( $table_content_row, $value['ticket_name'] );

			//add extra field data to row
			foreach( $extra_field_array as $extra_field ){
				$extra_field_meta_key = $extra_field['name'];
				$post_meta_value = get_post_meta( $key, $extra_field_meta_key, true );        

				if( $extra_field['type'] == 'radio' && isset( $extra_field['type_radio_arr'][$post_meta_value] ) ) {
					$post_meta_value = $extra_field['type_radio_arr'][$post_meta_value];
				}

				if( $extra_field['type'] == 'checkbox' ) {
					$defined_checkbox_arr = $extra_field['type_checkbox_arr'];
					$saved_checkbox_arr   = maybe_unserialize( $post_meta_value );

					$post_meta_value = '';
					if ( is_array( $defined_checkbox_arr ) && count( $defined_checkbox_arr ) > 0 && is_array( $saved_checkbox_arr ) && count( $saved_checkbox_arr ) > 0 ) {
						$selected_checkbox = array_intersect_key( $defined_checkbox_arr, array_flip( $saved_checkbox_arr ) );
						$post_meta_value   = join( ', ', $selected_checkbox );
					}
				}

				if( $extra_field['type'] == 'date' ) {
					$date_options       = Helper::get_date_formats();
					$selected_format    = Helper::get_option( 'date_format' );
					$post_meta_value    = !empty($post_meta_value) ? ( !empty($selected_format) ? date_i18n( $date_options[$selected_format], strtotime($post_meta_value) ) : date_i18n( get_option( 'date_format' ), strtotime($post_meta_value ))) : '';
				}

				array_push( $table_content_row, "=\"" . $post_meta_value . "\"" );
			}

			fputcsv(
				$output,
				$table_content_row
			);

		}

		// Close output file stream
		fclose( $output );

		die();
	}

    /**
     * Attendee qr callback
     * 
     * @param [integer] $attendee_id
     * @param [integer] $event_id
     * @return void
     */
    function etn_pro_ticket_qr_cb( $attendee_id, $event_id ) {
        ?>
        <p class="etn-ticket-qr-code">
            <?php 
            echo esc_html__( "Scan the QR Code: ", "eventin-pro" ); 
            ?>
        </p>
        <img class="etn-qrImage" src="" alt="" id="qrImage" />
        <?php
    }

    /**
     * Attendee ticket id callback
     * 
     * @param [integer] $attendee_id
     * @param [integer] $event_id
     * @return void
     */
    function etn_pro_ticket_id_cb( $attendee_id, $event_id ) {
        $unique_id          = get_post_meta( $attendee_id, 'etn_unique_ticket_id', true );
        $ticket_verify_url  = admin_url('/edit.php?post_type=etn-attendee&etn_action=ticket_scanner');
        $ticket_verify_url  .= "&attendee_id=$attendee_id&ticket_id=$unique_id";
        ?>
        <li class="etn-ticket-body-top-li"><?php echo esc_html__( "ID:", "eventin" ); ?>
            <p class="etn-ticket-id" id="ticketUnqId"  data-ticketverifyurl="<?php echo esc_url( $ticket_verify_url )?>"><?php echo esc_html( $unique_id ); ?></p>
        </li>
        <?php
    }

    /**
     * scanner module working functionalities
     *
     * @return void
     */

    public function scanner_module_functionalities() {
        if ( isset( $_GET['etn_action'] ) && sanitize_text_field( $_GET['etn_action'] ) == 'ticket_scanner' ) {

            if ( isset( $_GET['security'] ) ) {

                if ( is_user_logged_in() ) {
                    if ( ! wp_verify_nonce( sanitize_text_field( $_GET['security'] ), 'scanner_nonce_value' ) ) {
                        $response = [
                            'status_code' => 0,
                            'messages'    => [ esc_html__( 'Nonce is not valid! Please try again.', 'eventin-pro' ) ],
                            'content'     => [],
                        ];
                        wp_send_json_error( $response );
                        exit();
                    } else {
                        // ajax response
                        if ( isset( $_GET['ticket_id'] ) && isset( $_GET['attendee_id'] ) ) {
                            if ( isset( $_GET['ticket_info'] ) ) {
                                $response = $this->validate_ticket( $_GET['ticket_id'], $_GET['attendee_id'], absint( $_GET['ticket_info'] ) );
                                wp_send_json_success( $response );
                                exit();
                            } else if ( isset( $_GET['scanner_active'] ) ) {
                                $response = $this->validate_ticket( $_GET['ticket_id'], $_GET['attendee_id'] );
                                wp_send_json_success( $response );
                                exit();
                            }
                        }
                    }
                } else {
                    $status_code             = 3;
                    $content['redirect_url'] = wp_login_url( admin_url('/edit.php?post_type=etn-attendee&etn_action=ticket_scanner') );
                    $messages[]              = esc_html__( 'Organiser is not logged in. Please login first.', 'eventin' );

                    $response = [
                        'status_code' => $status_code,
                        'messages'    => $messages,
                        'content'     => $content,
                    ];

                    wp_send_json_error( $response );
                    exit();
                }
            } else {
                if ( is_user_logged_in() && current_user_can('manage_etn_attendee') ) {

                    // copied url from third party
                    if ( isset( $_GET['ticket_id'] ) && isset( $_GET['attendee_id'] ) && !isset( $_GET['scanner_active'] ) ) {
                        $settings                    = Helper::get_settings();
                        $attendee_verification_style = isset( $settings["attendee_verification_style"] ) ? $settings["attendee_verification_style"] : 'on';
                        $ticket_info = false;
                        if ( $attendee_verification_style ) {
                            $ticket_info = true;
                        }
                        $scanned_response = $this->validate_ticket( $_GET['ticket_id'], $_GET['attendee_id'], $ticket_info );
                    }

                    // include scanner file
                    if ( !isset( $_GET['scanner_active'] ) || ( isset( $_GET['scanner_active'] ) && $_GET['scanner_active'] != 'true' ) ) {
                        if ( file_exists( \Wpeventin_Pro::core_dir() . "attendee/scanner.php" ) ) {
                            include_once \Wpeventin_Pro::core_dir() . "attendee/scanner.php";
                        }
                    }
                } else {
                    $new_redirect_url = admin_url('/edit.php?post_type=etn-attendee&etn_action=ticket_scanner');
                    if(isset( $_GET['ticket_id'] )){
                        $new_redirect_url .= '&ticket_id=' . sanitize_text_field(  $_GET['ticket_id'] );
                    }

                    if(isset( $_GET['attendee_id'] )){
                        $new_redirect_url .= '&attendee_id=' . absint( $_GET['attendee_id'] );
                    }
                    wp_safe_redirect(
                        wp_login_url( $new_redirect_url )
                    );
                    exit();
                }
            }

            die();
        }

        return;
    }

    /**
     * check ticket id from qr scanner is valid and update ticket status accordingly
     *
     * @return array status_code, messages, content
     */
    public function validate_ticket( $ticket_id, $attendee_id, $ticket_info = 0 ) {
        $status_code    = 0;
        $messages       = $content      = [];
        $request        = [
            'ticket_id'     => $ticket_id,
            'attendee_id'   => $attendee_id,
        ];

        if ( is_user_logged_in() && current_user_can('manage_etn_attendee') ) {
            // pass input field for checking empty value
            $inputs_field = [
                ['name' => 'attendee_id', 'required'   => true, 'type' => 'number'],
                ['name' => 'ticket_id', 'required'   => true, 'type' => 'text'],
            ];

            $validation = Helper::input_field_validation( $request, $inputs_field );
            if ( !empty( $validation['status_code'] ) && $validation['status_code'] == true ) {
                $input_data  = $validation['data'];
                
                $attendee_id = $input_data['attendee_id'];
                $ticket_id   = $input_data['ticket_id'];

                if ( $ticket_info ) {
                    if ( !empty( $attendee_id ) && !empty( $ticket_id ) ) {
                        $event_id = get_post_meta( $attendee_id, 'etn_event_id', true );
                        if ( !empty( $event_id ) ) {
                            $event_name    = get_post_field( 'post_title', $event_id, 'raw' );
                            $attendee_name = get_post_meta( $attendee_id, 'etn_name', true );
                            $ticket_name   = !empty( get_post_meta($attendee_id,'ticket_name',true) ) ? html_entity_decode( get_post_meta($attendee_id,'ticket_name',true), ENT_QUOTES | ENT_HTML5, 'UTF-8') : ETN_DEFAULT_TICKET_NAME;

                            if ( !empty( $event_name ) && !empty( $attendee_name )  && !empty( $ticket_name )) {
                                $status_code = 1;
                                $msg         = esc_html__( 'ok', 'eventin-pto' );
                                $content     = [
                                    'event_name'    => $event_name,
                                    'attendee_name' => esc_html__('Attendee: ', 'eventin-pro'). $attendee_name,
                                    'ticket_name'   => esc_html__('Ticket Type: ', 'eventin-pro'). $ticket_name,
                                    'ticket_Message'   => esc_html__('Want to let him in? ', 'eventin-pro'),
                                ];
                            } else {
                                $msg  = esc_html__( 'Information is missing for this ticket. Please try again.', 'eventin-pto' );
                            }
                        } else {
                            $msg  = esc_html__( 'Event not found for this ticket.', 'eventin-pto' );
                        }
                    } else {
                        $msg  = esc_html__( 'Attendee ID or Ticket ID is missing', 'eventin-pto' );
                    }

                    $messages[]  = $msg;
                } else {
                    $ticket_status_data = $this->check_ticket_id( $attendee_id, $ticket_id );
                    $messages[]         = $ticket_status_data['msg'];

                    if ( !empty( $ticket_status_data['update_status'] ) ) { 
                        $status_code = $ticket_status_data['update_status'];
                        $content     = [
                            'name' => get_post_meta( $attendee_id, 'etn_name', true ),
                        ];
                    } 
                }
            } else {
                $status_code = $validation['status_code'];
                $messages    = $validation['messages'];
            }
        } else {
            $status_code             = 3;
            $content['redirect_url'] = wp_login_url( admin_url('/edit.php?post_type=etn-attendee&etn_action=ticket_scanner') );
            $messages[]              = esc_html__( 'Organiser must be logged in to backend panel and should have attendee manage permission.', 'eventin' );
        }

        return [
            'status_code' => $status_code,
            'messages'    => $messages,
            'content'     => $content,
        ];

    }

    /**
     * check ticket status and update
     *
     * @param [type] $attendee_id
     * @param [type] $ticket_id
     * @return array
     */
    public function check_ticket_id( $attendee_id = null, $ticket_id = null ) {
        $msg           = '';
        $update_status = false;

        if ( !empty( $attendee_id ) && !empty( $ticket_id ) ) {
            $unique_id = get_post_meta( $attendee_id, 'etn_unique_ticket_id', true );

            if ( $unique_id == $ticket_id ) {
                $ticket_status = get_post_meta( $attendee_id, 'etn_attendeee_ticket_status', true );
                if ( $ticket_status == 'used' ) {
                    $update_status = 1;
                    $msg           = esc_html__( 'Ticket is already used.', 'eventin' );
                } else {
                    update_post_meta( $attendee_id, 'etn_attendeee_ticket_status', 'used' );
                    $update_status = 2;
                    $msg           = esc_html__( 'The Ticket is Valid. Successfully Checked in.', 'eventin' );
                }
            } else {
                $msg = esc_html__( 'Ticket id doesn\'t match. Please try again.', 'eventin' );
            }
        }

        $response = [
            'msg'           => $msg,
            'update_status' => $update_status,
        ];

        return $response;
    }
}
