<?php

namespace Etn_Pro\Core\Event;

use Exception;

defined( 'ABSPATH' ) || exit;

class Api_Schedules extends \Etn\Base\Api_Handler {

    /**
     * define prefix and parameter patten
     *
     * @return void
     */
    public function config() {
        $this->prefix = 'schedules';
        $this->param  = ''; // /(?P<id>\w+)/
    }

    /**
     * Get all schedules data through api
     *
     * @return array
     */
    public function get_all() {
        $status_code = 0;
        $messages    = $content    = [];
        $request     = $this->request;

        try {

            $schedules = get_posts( [
                'post_type'   => 'etn-schedule',
                'numberposts' => '-1',
                'post_status' => 'publish',
            ] );

            if ( is_wp_error( $schedules ) ) {
                return [
                    'status_code' => 409,
                    'messages'    => [__( 'Could not get schedules', 'eventin-apro' )],
                    'content'     => $schedules->get_error_message(),
                ];
            }

            return [
                'status_code' => 200,
                'messages'    => [
                    __( 'Success', 'eventin-apro' ),
                ],
                'content'     => $schedules,
            ];
        } catch ( \Exception $e ) {
            return [
                'status_code' => 404,
                'messages'    => [__( 'Something went wrong! Try again!', 'eventin-apro' )],
                'content'     => $e->getMessage(),
            ];
        }

    }

}

new Api_Schedules();