<?php

namespace Etn_Pro\Core\Modules\Minmax;

defined('ABSPATH') || die();

class Minmax {
    use \Etn\Traits\Singleton;

    public function init(){
        if( class_exists( 'Woocommerce' ) ){
            add_filter( "etn_event_meta_fields_after_ticket", [$this, "event_min_max_meta"] );
            add_action( 'etn_before_add_to_cart_total_price', [$this, 'show_min_max_in_event_form'], 9, 3 );
        }
    }

    /**
     * Add extra field to event form
     *
     */
    public function event_min_max_meta( $meta_box_fields ) {

        $meta_box_fields_min_max['etn_min_ticket'] = [
            'label'    => esc_html__( 'Minimum Purchase Qty', 'eventin-pro' ),
            'type'     => 'number',
            'default'  => '',
            'value'    => '',
            'desc'     => esc_html__( 'minimum ticket purchase per order', 'eventin-pro' ),
            'priority' => 1,
            'placeholder' => esc_html__( '0', 'eventin' ),
            'attr'     => ['class' => 'etn-label-item etn-set-min-qty'],
        ];
        $meta_box_fields_min_max['etn_max_ticket'] = [
            'label'    => esc_html__( 'Maximum Purchase Qty', 'eventin-pro' ),
            'type'     => 'number',
            'default'  => '',
            'value'    => '',
            'placeholder' => esc_html__( '0', 'eventin' ),
            'desc'     => esc_html__( 'maximum ticket purchase per order', 'eventin-pro' ),
            'priority' => 1,
            'attr'     => ['class' => 'etn-label-item etn-set-max-qty'],
        ];
        $meta_box_fields['etn_show_min_max_text'] = [
            'label'        => esc_html__( 'Show Min Max Qty Text In Form', 'eventin-pro' ),
            'desc'         => esc_html__( 'Set if you want to show min max qty information inside form', "eventin-pro" ),
            'type'         => 'checkbox',
            'left_choice'  => 'yes',
            'right_choice' => 'no',
            'attr'         => ['class' => 'etn-label-item etn-limit-event-ticket'],
        ];

        $meta_box_fields['etn_ticket_variations']['options'] += $meta_box_fields_min_max;

        return $meta_box_fields;
    }

    /**
     * show minimum and maximum ticket purchaseable notice for each variation ticket
     *
     * @param [int] $single_event_id
     * @param [int] $variation_index
     * @param [array] $ticket_variation
     * @return void
     */
    public function show_min_max_in_event_form( $single_event_id, $variation_index, $ticket_variation ) {
        $etn_show_min_max_text = ( !empty( get_post_meta( $single_event_id, 'etn_show_min_max_text', true ) ) && get_post_meta( $single_event_id, 'etn_show_min_max_text', true ) == 'on' ) ? 1 : 0 ;

        if ( $etn_show_min_max_text ) {
            $etn_avaiilable_tickets = !empty( absint( $ticket_variation['etn_avaiilable_tickets'] ) ) ? absint( $ticket_variation['etn_avaiilable_tickets'] ) : 100000;
            $etn_sold_tickets       = absint( $ticket_variation['etn_sold_tickets'] );
            $remaining_ticket       = $etn_avaiilable_tickets - $etn_sold_tickets;

            if ( $remaining_ticket > 0 ) {
                $etn_min_ticket = !empty( absint( $ticket_variation['etn_min_ticket'] ) ) ? absint( $ticket_variation['etn_min_ticket'] ) : 1;
                $etn_max_ticket = !empty( absint( $ticket_variation['etn_max_ticket'] ) ) ? absint( $ticket_variation['etn_max_ticket'] ) : $etn_avaiilable_tickets;
                $etn_max_ticket = min( $remaining_ticket, $etn_max_ticket );

                if ( $etn_min_ticket > $etn_max_ticket ) {
                    $swap           = $etn_min_ticket;
                    $etn_min_ticket = $etn_max_ticket;
                    $etn_max_ticket = $swap;
                }
                ?>
                <div class='etn-min-max-ticket-form-text min-max-purchase-notice-<?php echo esc_attr( absint( $variation_index ) ); ?>'><?php echo esc_html__('You can purchase ', 'eventin-pro') . $etn_min_ticket . '-'. $etn_max_ticket . esc_html__(' tickets at once ', 'eventin-pro'); ?></div>
                <?php
            }
        }
    }

}
