<?php

namespace Etn_Pro\Core\Modules\Sells_Engine\Stripe;

defined( 'ABSPATH' ) || die();

/***
* Stripe activities.
*/
class Stripe {
	use \Etn\Traits\Singleton;
	/**
	 * Fire stripe hooks.
	 */
	public function init() {

		// enqueue scripts.
		$this->enqueue_scripts();
		// load stripe script.
		$this->etn_stripe()->_load_script();
		add_filter( 'etn_pro/stripe/ticket_template', array( $this,'ticket_template' ) ,10 , 1 );
	}

	/**
	 * Enqueue scripts.
	 */
	public function enqueue_scripts() {
		add_action( 'wp_enqueue_scripts', array( $this , 'js_css_public' ) );
	}

	/**
	 * Load Strip script.
	 */
	public function etn_stripe() {
		return \Etn_Pro\Core\Modules\Sells_Engine\Stripe\Payments\Setup::instance();
	}

	/**
	 * Frontend scripts.
	 */
	public function js_css_public() {
		wp_enqueue_script( 'etn-stripe-public', ETN_PRO_CORE . 'modules/sells-engine/stripe/assets/js/etn-stripe.js', ['jquery'], \Wpeventin_Pro::version(), false );

		$thank_you_data 						= get_page_by_path( 'etn_stripe_thank_you' );
		$localized_data                         = [];
		$localized_data['ajax_url']             = admin_url( 'admin-ajax.php' );
		$localized_data['stripe_payment_nonce'] = wp_create_nonce( 'stripe_payment_nonce_value' );
		$localized_data['redirect_url'] 		= get_page_link( $thank_you_data->ID );
		$localized_data['common_err_msg'] 		= esc_html__( 'Something went wrong, Please try again.', 'eventin-pro' );

		wp_localize_script( 'etn-stripe-public', 'localized_stripe_data', $localized_data );
	}

	/**
	 * Get an moderate entropy unique id, specially for generating uuid for pledge
	 * @param int $prefix_len
	 * @return string
	 */
	public function get_uuid( $prefix_len = 6 ) {

		$text_shuffle = '@ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789';
		$uuid         = substr( str_shuffle( $text_shuffle ) , 0 , $prefix_len ) . '-' . time();

		return $uuid;
	}

	/**
	 * Post attendee data
	 */
	public function insert_attendee_stripe() {
		$response = array( 'success' => 0, 'message' => esc_html__( 'Something is wrong', 'eventin-pro' ), 'data'=> array() , 'error'=> array()  );
		$result = '';
		$post_arr = filter_input_array( INPUT_POST, FILTER_SANITIZE_SPECIAL_CHARS );

		$settings = \Etn\Core\Settings\Settings::instance()->get_settings_option();

		$attendee_registration     = ( !empty( $settings["attendee_registration"] ) ? true : false );
		$etn_sells_engine_stripe   = ( ! empty( $settings['etn_sells_engine_stripe'] ) ? 'checked': '' );
		$etn_stripe_test_mode      = !empty( $settings['etn_stripe_test_mode'] ) ? $settings['etn_stripe_test_mode'] : '';
		$get_data                  = \Etn_Pro\Utils\Helper::instance()->retrieve_country_currency( true );
		$currency_code             = !empty( $get_data ) ? $get_data['currency'] : 'USD';

		$keys     = '';
		if ( '' !== $etn_stripe_test_mode ) {
			$keys = ! empty( $settings['stripe_test_publishable_key'] ) ? $settings['stripe_test_publishable_key'] : '';
		}
		else {
			$keys = ! empty( $settings['stripe_live_publishable_key'] ) ? $settings['stripe_live_publishable_key'] : '';
		}

		if ( ! empty( $post_arr['attendee_data'] ) ) {
			$attendee_data        = array();
			// re-format data for post attendee.
			foreach ($post_arr['attendee_data'] as $key => $value) {
				$attendee_data[$value['name']]  = $value['value'];
			}

			if ( ! empty( $attendee_data['ticket_name'] ) && ! empty( $attendee_data['ticket_quantity'] ) ) {
				$etn_ticket_variations = array();

				foreach ( $attendee_data['ticket_quantity'] as $key => $value ) {
						$etn_ticket_variations[$key]['etn_ticket_slug'] = $attendee_data['ticket_slug'][$key];
						$etn_ticket_variations[$key]['etn_ticket_name'] = $attendee_data['ticket_name'][$key];
						$etn_ticket_variations[$key]['etn_ticket_qty']  = $value;
				}
				$attendee_data['picked_ticket_variations'] = $etn_ticket_variations;
			}

			if($attendee_registration){
				$result = \Etn\Core\Attendee\Hooks::instance()->add_attendee_data( 'stripe' , $attendee_data );
			}

			if ( 'success' == $result ) {

				$data['currency_code']  = $currency_code;
				$data['keys']           = $keys;
				$data['fname']           = !empty( $attendee_data['client_fname'] ) ? $attendee_data['client_fname'] : '';
				$data['lname']           = !empty( $attendee_data['client_lname'] ) ? $attendee_data['client_lname'] : '';
				$data['email']          = !empty( $attendee_data['client_email'] ) ? $attendee_data['client_email'] : '';
				$data['event_id']       = !empty( $attendee_data['add-to-cart'] ) ? $attendee_data['add-to-cart'] : '';
				$data['event_name']     = ! empty( $attendee_data['event_name'] ) ? $attendee_data['event_name'] : '';
				$data['etn_status_update_token'] = !empty( $attendee_data['attendee_info_update_key'] ) ? $attendee_data['attendee_info_update_key'] : 0;
				$data['etn_total_qty']  = !empty( $attendee_data['etn_total_qty'] ) ? $attendee_data['etn_total_qty'] : 0;
				$data['etn_total_price']= !empty( $attendee_data['etn_total_price'] ) ? floatval( $attendee_data['etn_total_price'] ) : 0.00;
				$data['picked_ticket_variations'] = !empty( $attendee_data['picked_ticket_variations'] ) ? $attendee_data['picked_ticket_variations'] : [] ;
				$data['check_id']       = \Etn_Pro\Core\Modules\Sells_Engine\Stripe\Stripe::instance()->get_uuid();
				$data['image_url']      = ETN_PRO_CORE . 'modules/sells-engine/stripe/assets/images/etn-image.png';

				$stripe_order_id  = $this->stripe_order_creation( $data );
				$data['order_id'] = $stripe_order_id;
				$response = array( 'success' => 1, 'message' => esc_html__( 'Attendee insert successfully', 'eventin-pro' ) , 'data'=> $data , 'error'=> array() );

			}elseif(!($attendee_registration) && ('checked' == $etn_sells_engine_stripe) ) {
				$data['currency_code']  = $currency_code;
				$data['keys']           = $keys;
				$data['fname']           = !empty( $attendee_data['client_fname'] ) ? $attendee_data['client_fname'] : '';
				$data['lname']           = !empty( $attendee_data['client_lname'] ) ? $attendee_data['client_lname'] : '';
				$data['email']          = !empty( $attendee_data['client_email'] ) ? $attendee_data['client_email'] : '';
				$data['event_id']       = !empty( $attendee_data['add-to-cart'] ) ? $attendee_data['add-to-cart'] : '';
				$data['event_name']     = ! empty( $attendee_data['event_name'] ) ? $attendee_data['event_name'] : '';
				$data['etn_status_update_token'] = !empty( $attendee_data['attendee_info_update_key'] ) ? $attendee_data['attendee_info_update_key'] : 0;
				$data['etn_total_qty']  = !empty( $attendee_data['etn_total_qty'] ) ? $attendee_data['etn_total_qty'] : 0;
				$data['etn_total_price']= !empty( $attendee_data['etn_total_price'] ) ? floatval( $attendee_data['etn_total_price'] ) : 0.00;
				$data['picked_ticket_variations'] = !empty( $attendee_data['picked_ticket_variations'] ) ? $attendee_data['picked_ticket_variations'] : [] ;
				$data['check_id']       = \Etn_Pro\Core\Modules\Sells_Engine\Stripe\Stripe::instance()->get_uuid();
				$data['image_url']      = ETN_PRO_CORE . 'modules/sells-engine/stripe/assets/images/etn-image.png';

				$stripe_order_id  = $this->stripe_order_creation( $data );
				$data['order_id'] = $stripe_order_id;
	
				$response = array( 'success' => 1, 'message' => esc_html__( 'Added popup successfully', 'eventin-pro' ) , 'data'=> $data , 'error'=> array() );

			}else{
				$response = array( 'success' => 0, 'message' => esc_html__( 'Attendee is not insert successfully', 'eventin-pro' ), 'data'=> array() , 'error'=> array()  );
			}
		} 

		return wp_send_json_success( $response );
	}

	/**
	* Render ticket template.
	*/
	public function ticket_template($single_event_id) {
		// for single events
		?>
		<div class="etn-single-event-ticket-wrap">
			<?php \Etn\Utils\Helper::woocommerce_ticket_widget( $single_event_id );  ?>
		</div>
		<?php
	}

	
	/**
	 * stripe order creation
	 * 
	 * @return int
	 */
    public function stripe_order_creation( $data = [] ) {
        $stripe_order_id = wp_insert_post( [
            'post_title'  => esc_html__( 'Stripe order', 'eventin-pro' ),
            'post_type'   => 'etn-stripe-order',
            'post_status' => 'publish',
        ] );
        
        wp_update_post( ['ID' => $stripe_order_id] );

		$etn_ticket_variations_picked   = $data['picked_ticket_variations'];
        $etn_variation_total_price      = $data['etn_total_price'];
        $etn_variation_total_quantity   = $data['etn_total_qty'];
        $etn_status_update_key          = $data['etn_status_update_token'];
        $invoice_key                    = $data['check_id'];
        $currency                       = $data['currency_code'];

        $billing_first_name           	= $data['fname'];
        $billing_last_name            	= $data['lname'];
        $billing_email                	= $data['email'];
		$billing_country				= '';

        $order_metas = [
            '_order_key'                    => $invoice_key,
            '_billing_first_name'           => $billing_first_name,
            '_billing_last_name'            => $billing_last_name,
            '_billing_email'                => $billing_email,
            '_order_shipping'               => '',
            '_order_shipping_tax'           => '',
            '_order_tax'                    => '',
            '_billing_country'              => $billing_country,
            '_order_currency'               => $currency,
            'etn_ticket_variations_picked'  => $etn_ticket_variations_picked,
            'etn_variation_total_quantity'  => $etn_variation_total_quantity,
            'etn_variation_total_price'     => $etn_variation_total_price,
            'etn_status_update_key'         => $etn_status_update_key,
            'etn_payment_status'         	=> 'Pending',
        ];
        foreach ( $order_metas as $key => $value ) {
            update_post_meta( $stripe_order_id, $key, $value );
        }

        return $stripe_order_id;
    }

	/**
	 * get order details through order id
	 *
	 * @param [int] $order_id
	 * @return array
	 */
	public static function stripe_order_details( $order_id = null ) {
		global $wpdb;
		$table_name = ETN_EVENT_PURCHASE_HISTORY_TABLE;

		$query_string = "SELECT * FROM $table_name WHERE form_id = %d";
		$order        = $wpdb->get_row( $wpdb->prepare("$query_string", $order_id) );
		
		return $order;
	}
}
