<?php

namespace Etn_Pro\Core\Settings;

defined( "ABSPATH" ) || exit;

class Settings extends \Etn\Core\Settings\Base\Config {

    use \Etn_Pro\Traits\Singleton;

    public $textdomain = 'eventin-pro';

    /**
     * Call all hooks
     */
    public function init() {
        // add filter to add more settings
        add_filter( 'eventin/settings/pro_settings', [$this, 'add_general_settings'] );
        add_filter( 'etn_event_templates', [$this, 'add_event_pro_template_options'] );
        add_filter( 'etn_speaker_templates', [$this, 'add_speaker_pro_template_options'] );

        add_action( 'etn_after_notification_settings', [$this, 'after_notification_settings'] );
        add_action( 'etn_after_parchase_report_settings', [$this, 'etn_after_purchase_report_settings'] );

        add_action( 'etn_after_purchase_report_settings', [$this, 'etn_after_purchase_report_settings_fields'] );
        add_action( 'etn_after_woocommerce_fields_settings', [$this, 'etn_after_woocommerce_fields_settings'] );

        add_action( 'etn_after_integration_settings', [$this, 'after_integration_settings_grounhogg'], 10 );
        add_action( 'etn_after_integration_settings', [$this, 'after_integration_settings_google_mapapi'], 15 );

        add_action( 'etn_after_integration_settings_inner_tab_heading', [$this, 'after_integration_settings_inner_tabs'] );

    }

    /**
     * After Notification Settings
     *
     * @since 2.4.2
     *
     * @return void
     */
    public function after_notification_settings() {

        if ( file_exists( ETN_PRO_DIR . "/core/settings/views/email-notification-settings.php" ) ) {
            include_once ETN_PRO_DIR . "/core/settings/views/email-notification-settings.php";
        }

    }

    /**
     * After purchase report Settings
     *
     * @since 2.4.2
     *
     * @return void
     */
    public function etn_after_woocommerce_fields_settings() {

        $settings = \Etn\Core\Settings\Settings::instance()->get_settings_option();
        $etn_count_refund_price = ( isset( $settings['etn_count_refund_price'] ) ? 'checked' : '' );
        $etn_show_print_download_on_thankyou = ( isset( $settings['etn_show_print_download_on_thankyou'] ) ? 'checked' : '' );

        ?>
        <div class="attr-form-group etn-label-item" id="etn-count-refund-price-wrap">
            <div class="etn-label">
                <label>
                    <?php esc_html_e( 'Count Refunded / Failed Order In Purchase Report', 'eventin-pro' );?>
                </label>
                <div class="etn-desc"> <?php esc_html_e( 'Include cost for refunded / failed tickets in purchase history.', 'eventin-pro' );?> </div>
            </div>
            <div class="etn-meta">
                <input id='etn_count_refund_price' type="checkbox" <?php echo esc_html( $etn_count_refund_price ); ?> class="etn-admin-control-input etn-form-modalinput-paypal_sandbox" name="etn_count_refund_price" />
                <label for="etn_count_refund_price" class="etn_switch_button_label"></label>
            </div>
        </div>
            
        <div class="attr-form-group etn-label-item" id="etn-show-print-download-wrap">
            <div class="etn-label">
                <label>
                    <?php esc_html_e( 'Show Print / Download Invoice On Thankyou Page', 'eventin-pro' );?>
                </label>
                <div class="etn-desc"> <?php esc_html_e( 'Show button for downloading / printing order invoice.', 'eventin-pro' );?> </div>
            </div>
            <div class="etn-meta">
                <input id='etn_show_print_download_on_thankyou' type="checkbox" <?php echo esc_html( $etn_show_print_download_on_thankyou ); ?> class="etn-admin-control-input etn-form-modalinput-paypal_sandbox" name="etn_show_print_download_on_thankyou" />
                <label for="etn_show_print_download_on_thankyou" class="etn_switch_button_label"></label>
            </div>
        </div>
        <?php
    }

    /**
     * After purchase report Settings
     *
     * @since 2.4.2
     *
     * @return void
     */
    public function etn_after_purchase_report_settings_fields() {

        $settings = \Etn\Core\Settings\Settings::instance()->get_settings_option();
        $etn_stripe_test_mode = (isset($settings['etn_stripe_test_mode']) ? 'checked' : '');
        $stripe_test_publishable_key = (isset($settings['stripe_test_publishable_key']) ? $settings['stripe_test_publishable_key'] : '');
        $stripe_test_secret_key = (isset($settings['stripe_test_secret_key']) ? $settings['stripe_test_secret_key'] : '');
        $stripe_live_publishable_key = (isset($settings['stripe_live_publishable_key']) ? $settings['stripe_live_publishable_key'] : '');
        $stripe_live_secret_key = (isset($settings['stripe_live_secret_key']) ? $settings['stripe_live_secret_key'] : '');
        
        $etn_sells_engine_stripe = (isset($settings['etn_sells_engine_stripe']) ? 'checked' : '');
        $stripe_class = ( $etn_sells_engine_stripe == 'checked' ) ?  'stripe_section' : 'stripe_section_hide';

        $etn_stripe_test_mode = (isset($settings['etn_stripe_test_mode']) ? 'checked' : '');
        $test_mode_class = ( $etn_stripe_test_mode == 'checked' ) ?  'test_key_section' : 'test_key_section_hide';

        ?>

        <div class="attr-form-group etn-label-item etn-label-top">
            <div class="etn-label">
                <label>
                    <?php esc_html_e('Stripe', 'eventin-pro'); ?>
                </label>
                <div class="etn-desc mb-2"> <?php esc_html_e('Enable stripe payment', 'eventin-pro'); ?> </div>
            </div>
            <div class="etn-meta">
                <input id="etn_sells_engine_stripe" type="checkbox" <?php echo esc_html($etn_sells_engine_stripe); ?> class="etn-admin-control-input" name="etn_sells_engine_stripe" value="stripe" />
                <label for="etn_sells_engine_stripe" data-left="Yes" data-right="No" class="etn_switch_button_label"></label>
            </div>
            <div class="stripe-payment-methods <?php echo esc_attr($stripe_class); ?>">            
                <div class="attr-form-group etn-label-item etn-label-top">
                    <div class="etn-label">
                        <label>
                            <?php esc_html_e('Test Mode', 'eventin-pro'); ?>
                        </label>
                        <div class="etn-desc"> <?php esc_html_e('Enable test mode', 'eventin-pro'); ?> </div>
                    </div>
                    <div class="etn-meta">
                        <input id="etn_stripe_test_mode" type="checkbox" <?php echo esc_html($etn_stripe_test_mode); ?> class="etn-admin-control-input" name="etn_stripe_test_mode" />
                        <label for="etn_stripe_test_mode" data-left="Yes" data-right="No" class="etn_switch_button_label"></label>
                    </div>
                </div>

                <div class="test-key-wrapper <?php echo esc_attr($test_mode_class); ?>">
                    <?php
                    $markup_fields_one = [
                        'stripe_test_publishable_key' => [
                            'item' => [
                                'label'    => esc_html__( 'Test Publishable key', 'eventin-pro' ),
                                'desc'     => esc_html__( 'Place Publishable key', 'eventin-pro' ),
                                'type'     => 'password',
                                'place_holder' => esc_html__('Test Publishable key here', 'eventin-pro'),
                                'attr'     => ['class' => 'attr-form-group etn-label-item', 'input_class'=> 'etn-setting-input attr-form-control'],
                            ],
                            'data' => [ 'stripe_test_publishable_key' => $stripe_test_publishable_key ],
                        ],
                        'stripe_test_secret_key' => [
                            'item' => [
                                'label'    => esc_html__( 'Test Secret key', 'eventin-pro' ),
                                'desc'     => esc_html__( 'Place Secret key', 'eventin-pro' ),
                                'type'     => 'password',
                                'place_holder' => esc_html__('Test secret key here', 'eventin-pro'),
                                'attr'     => ['class' => 'attr-form-group etn-label-item', 'input_class'=> 'etn-setting-input attr-form-control'],
                            ],
                            'data' => [ 'stripe_test_secret_key' => $stripe_test_secret_key ],
                        ],
                    ];
            
                    foreach ( $markup_fields_one as $key => $info ) {
                        $this->get_field_markup( $info['item'], $key, $info['data'] );
                    }
                    ?>
                </div>

                <div class="live-key-wrapper">
                    <?php
                    $markup_fields_two = [
                        'stripe_live_publishable_key' => [
                            'item' => [
                                'label'    => esc_html__( 'Live Publishable key', 'eventin-pro' ),
                                'desc'     => esc_html__( 'Place Publishable key', 'eventin-pro' ),
                                'type'     => 'password',
                                'place_holder' => esc_html__('Live Publishable key here', 'eventin-pro'),
                                'attr'     => ['class' => 'attr-form-group etn-label-item', 'input_class'=> 'etn-setting-input attr-form-control'],
                            ],
                            'data' => [ 'stripe_live_publishable_key' => $stripe_live_publishable_key ],
                        ],
                        'stripe_live_secret_key' => [
                            'item' => [
                                'label'    => esc_html__( 'Live Secret key', 'eventin-pro' ),
                                'desc'     => esc_html__( 'Place Secret key', 'eventin-pro' ),
                                'type'     => 'password',
                                'place_holder' => esc_html__('Live secret key here', 'eventin-pro'),
                                'attr'     => ['class' => 'attr-form-group etn-label-item', 'input_class'=> 'etn-setting-input attr-form-control'],
                            ],
                            'data' => [ 'stripe_live_secret_key' => $stripe_live_secret_key ],
                        ],
                    ];
            
                    foreach ( $markup_fields_two as $key => $info ) {
                        $this->get_field_markup( $info['item'], $key, $info['data'] );
                    }
                    ?>
                </div>

                <?php
                //add country and currency with symbol
                include(ETN_PRO_DIR.'/core/settings/views/country-info.php' );

                $etn_sells_engine_currency =  isset( $settings['etn_settings_country_currency']['options'] ) ? $settings['etn_settings_country_currency']['options'] : "";

                $default_country = isset($etn_sells_engine_currency['location']['country']) ? $etn_sells_engine_currency['location']['country'] : 'US-CA';

                $only_country = explode('-', $default_country);
                $defult_code = isset($countryList[$only_country[0]]['currency']['code']) ? $countryList[$only_country[0]]['currency']['code'] : 'USD';

                $default_currency = isset($etn_sells_engine_currency['currency']['name']) ? $etn_sells_engine_currency['currency']['name'] : $only_country[0].'-'.$defult_code;

                ?>

                <div class="attr-form-group etn-label-item currency-select-dropdown">
                    <div class="etn-label">
                        <label for="captcha-method"><?php esc_html_e( 'Currency', 'eventin-pro' );?></label>
                        <div class="etn-desc"> <?php esc_html_e( 'Select your currency', 'eventin-pro' );?> </div>
                    </div>
                    <div class="etn-meta">
                        <select id="etn_sells_engine_currency" name="etn_settings_country_currency[options][currency][name]" class="etn-setting-input attr-form-control etn-settings-select">
                            <?php
                            if(is_array($countryList) && sizeof($countryList) > 0){
                                foreach($countryList AS $key=>$value):
                                    $name = isset($value['info']['name']) ? $value['info']['name'] : '';
                                    $code = isset($value['currency']['code']) ? $value['currency']['code'] : '';
                                    $symbols = isset($value['currency']['symbol']) ? $value['currency']['symbol'] : '';
                                    $symbols_br = strlen($symbols) > 0 ? '('.$symbols.')' : '';
                                ?>
                                    <option value="<?php echo esc_attr($key.'-'.$code.'-'.$symbols);?>" <?php echo ($default_currency == $key.'-'.$code.'-'.$symbols) ? 'selected' : '';?>> <?php echo esc_html($name.' -- '.$code.$symbols_br);?> </option>
                                <?php	
                                
                                endforeach;
                            }
                            ?>
                        </select>
                    </div>
                </div>            
            </div>
        </div>
        
        <?php
    }

    /**
     * Add pro settings to general-settings tab
     *
     * @return void
     */
    public function add_general_settings( $settings_arr ) {
        $settings_arr['pro_details_options']  = ETN_PRO_DIR . "/core/settings/views/details-settings.php";
        $settings_arr['pro_attendee_options'] = ETN_PRO_DIR . "/core/settings/views/attendee-settings.php";
        return $settings_arr;
    }

    /**
     * Add more templates options for Event Single Page
     *
     * @param [type] $all_templates
     * @return void
     */
    public function add_event_pro_template_options( $all_templates ) {
        $all_templates['event-two']   = esc_html__( 'Template Two', 'eventin-pro' );
        $all_templates['event-three'] = esc_html__( 'Template Three', 'eventin-pro' );
        return $all_templates;
    }

    /**
     * Add more templates options for Speaker Single Page
     *
     * @param [type] $all_templates
     * @return void
     */
    public function add_speaker_pro_template_options( $all_templates ) {
        $all_templates['speaker-two']   = esc_html__( 'Template One Pro', 'eventin-pro' );
        $all_templates['speaker-three'] = esc_html__( 'Template Two Pro', 'eventin-pro' );

        return $all_templates;
    }

    /**
     * Add inner tabs for integration tab
     *
     */

    public function after_integration_settings_grounhogg(){
        $settings = \Etn\Core\Settings\Settings::instance()->get_settings_option();
        $etn_groundhogg_api = (isset($settings['etn_groundhogg_api']) ? 'checked' : '');
        $groundhogg_woocommerce_purchase = (isset($settings['groundhogg_woocommerce_purchase']) ? 'checked' : '');
        
        $groundhogg_attendee_email = (isset($settings['groundhogg_attendee_email']) ? 'checked' : '');
        
        $groundhogg_public_key = (isset($settings['groundhogg_public_key']) ? $settings['groundhogg_public_key'] : '');
        $groundhogg_token = (isset($settings['groundhogg_token']) ? $settings['groundhogg_token'] : '');
        $groundhogg_v3_route = (isset($settings['groundhogg_v3_route']) ? $settings['groundhogg_v3_route'] : '');
        $groundhogg_class = ( $etn_groundhogg_api == 'checked' ) ?  'groundhogg_section' : 'groundhogg_section_hide';
        ?>
        <div class="etn-settings-tab" id="groundhogg-options">
            <div class="attr-form-group etn-label-item etn-label-top">
                <div class="etn-label">
                    <label>
                        <?php esc_html_e('Groundhogg', 'eventin-pro'); ?>
                    </label>
                    <div class="etn-desc"> <?php esc_html_e('Enable groundhogg CRM', 'eventin-pro'); ?> </div>
                </div>
                <div class="etn-meta">
                    <input id="groundhogg_api" type="checkbox" <?php echo esc_html($etn_groundhogg_api); ?> class="etn-admin-control-input" name="etn_groundhogg_api" />
                    <label for="groundhogg_api" data-left="Yes" data-right="No" class="etn_switch_button_label"></label>
                </div>
            </div>

            <div class="groundhogg_block <?php echo esc_attr($groundhogg_class); ?>">
                <div class="attr-form-group etn-label-item">
                    <div class="etn-label">
                        <label class="etn-setting-label" for="groundhogg_public_key"><?php esc_html_e('Public key', 'eventin-pro'); ?></label>
                        <div class="etn-desc"> <?php esc_html_e('Place api public key here that you get from groundhogg contact', 'eventin-pro'); ?> </div>
                    </div>
                    <div class="etn-meta">
                        <div class="etn-secret-key">
                            <input type="password" class="etn-setting-input attr-form-control" name="groundhogg_public_key" value="<?php echo esc_attr($groundhogg_public_key); ?>" id="groundhogg_public_key" />
                            <span><i class="fa fa-eye-slash eye_toggle_click"></i></span>
                        </div>
                    </div>
                </div>
                <div class="attr-form-group etn-label-item etn-label-top">
                    <div class="etn-label">
                        <label class="etn-setting-label" for="groundhogg_token"><?php esc_html_e('Token', 'eventin-pro'); ?></label>
                        <div class="etn-desc"> <?php esc_html_e('Place groundhogg token', 'eventin-pro'); ?>
                        </div>
                    </div>
                    <div class="etn-meta">
                        <div class="etn-secret-key mb-2">
                            <input type="password" class="etn-setting-input attr-form-control" name="groundhogg_token" value="<?php echo esc_attr($groundhogg_token); ?>" id="groundhogg_token" />
                            <span><i class="fa fa-eye-slash eye_toggle_click"></i></span>
                        </div>
                        <div class="etn-desc"> <?php esc_html_e('Check the official documentation from', 'eventin-pro'); ?>
                            <a href="<?php echo esc_url('https://support.themewinter.com/docs/plugins/plugin-docs/eventin/groundhogg-integration/') ?>" target="_blank" rel="noopener"><?php esc_html_e(' here', 'eventin-pro'); ?></a>
                        </div>
                    </div>
                </div>
                <div class="attr-form-group etn-label-item">
                    <div class="etn-label">
                        <label class="etn-setting-label" for="groundhogg_v3_route"><?php esc_html_e('API v3 Route URL', 'eventin-pro'); ?></label>
                        <div class="etn-desc"> <?php esc_html_e('Place the API v3 route URL from Groundhogg settings->API. NOTE: Add "/contacts" at the end of the URL', 'eventin-pro'); ?> </div>
                    </div>
                    <div class="etn-meta">
                        <div class="etn-secret-key">
                            <input type="text" class="etn-setting-input attr-form-control" name="groundhogg_v3_route" value="<?php echo esc_attr($groundhogg_v3_route); ?>" id="groundhogg_v3_route" placeholder="<?php echo esc_attr__('https://mysite.com/wp-json/gh/v3/contacts', 'eventin-pro'); ?>" />
                        </div>
                    </div>
                </div>
                <div class="attr-form-group etn-label-item">
                    <div class="etn-label">
                        <label>
                            <?php esc_html_e('Disable creating contact with WooCommerce billing email', 'eventin-pro'); ?>
                        </label>
                        <div class="etn-desc"> <?php esc_html_e('Disable WooCommerce billing email as Groundhogg contact', 'eventin-pro'); ?> </div>
                    </div>
                    <div class="etn-meta">
                        <input id="groundhogg_woocommerce_purchase" type="checkbox" <?php echo esc_html($groundhogg_woocommerce_purchase); ?> class="etn-admin-control-input" name="groundhogg_woocommerce_purchase" />
                        <label for="groundhogg_woocommerce_purchase" data-left="Yes" data-right="No" class="etn_switch_button_label"></label>
                    </div>
                </div>
                <div class="attr-form-group etn-label-item">
                    <div class="etn-label">
                        <label>
                            <?php esc_html_e('Disable creating contact with attendee email', 'eventin-pro'); ?>
                        </label>
                        <div class="etn-desc"> <?php esc_html_e('Disable attendee email as Groundhogg contact', 'eventin-pro'); ?> </div>
                    </div>
                    <div class="etn-meta">
                        <input id="groundhogg_attendee_email" type="checkbox" <?php echo esc_html($groundhogg_attendee_email); ?> class="etn-admin-control-input" name="groundhogg_attendee_email" />
                        <label for="groundhogg_attendee_email" data-left="Yes" data-right="No" class="etn_switch_button_label"></label>
                    </div>
                </div>
            </div>
        </div>

        <?php

    }

    /**
     * Add google map api keys options
     *
     */

    public function after_integration_settings_google_mapapi(){
        $settings = \Etn\Core\Settings\Settings::instance()->get_settings_option();
        $etn_googlemap_api = (isset($settings['etn_googlemap_api']) ? 'checked' : '');
        $google_api_key = (isset($settings['google_api_key']) ? $settings['google_api_key'] : '');
        $googlemap_class = ( $etn_googlemap_api == 'checked' ) ?  'googlemap_section' : 'googlemap_section_hide';
        ?>

        <div class="etn-settings-tab" id="googlemap-options">
            <div class="attr-form-group etn-label-item etn-label-top">
                <div class="etn-label">
                    <label>
                        <?php esc_html_e('Google Map', 'eventin-pro'); ?>
                    </label>
                    <div class="etn-desc"> <?php esc_html_e('Enable Google Map', 'eventin-pro'); ?> </div>
                </div>
                <div class="etn-meta">
                    <input id="etn_googlemap_api" type="checkbox" <?php echo esc_html($etn_googlemap_api); ?> class="etn-admin-control-input" name="etn_googlemap_api" />
                    <label for="etn_googlemap_api" data-left="Yes" data-right="No" class="etn_switch_button_label"></label>
                </div>
            </div>

            <div class="googlemap_block <?php echo esc_attr($googlemap_class); ?>">
                <?php
                $markup_fields_one = [
                    'google_api_key' => [
                        'item' => [
                            'label'    => esc_html__( 'Map API key', 'eventin-pro' ),
                            'desc'     => esc_html__( 'Place Google map API key', 'eventin-pro' ),
                            'type'     => 'password',
                            'place_holder' => esc_html__('Google Map API key here', 'eventin-pro'),
                            'attr'     => ['class' => 'attr-form-group etn-label-item', 'input_class'=> 'etn-setting-input attr-form-control'],
                        ],
                        'data' => [ 'google_api_key' => $google_api_key ],
                    ],
                ];
        
                foreach ( $markup_fields_one as $key => $info ) {
                    $this->get_field_markup( $info['item'], $key, $info['data'] );
                }
                ?>
            </div>
        </div>
        <?php

    }

    /**
     * Add inner tabs for integration tab
     *
     */

    function after_integration_settings_inner_tabs() {
        ?>
        <li>
            <a class="etn-settings-tab-a" data-id="groundhogg-options">
                <?php echo esc_html__('Groundhogg', 'eventin-pro'); ?>
                <svg width="14" height="13" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 256 512"><path d="M64 448c-8.188 0-16.38-3.125-22.62-9.375c-12.5-12.5-12.5-32.75 0-45.25L178.8 256L41.38 118.6c-12.5-12.5-12.5-32.75 0-45.25s32.75-12.5 45.25 0l160 160c12.5 12.5 12.5 32.75 0 45.25l-160 160C80.38 444.9 72.19 448 64 448z"></path></svg>
            </a>
        </li>
        <li>
            <a class="etn-settings-tab-a" data-id="googlemap-options">
                <?php echo esc_html__('Google Map', 'eventin-pro'); ?>
                <svg width="14" height="13" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 256 512"><path d="M64 448c-8.188 0-16.38-3.125-22.62-9.375c-12.5-12.5-12.5-32.75 0-45.25L178.8 256L41.38 118.6c-12.5-12.5-12.5-32.75 0-45.25s32.75-12.5 45.25 0l160 160c12.5 12.5 12.5 32.75 0 45.25l-160 160C80.38 444.9 72.19 448 64 448z"></path></svg>
            </a>
        </li>
        <?php
    }

}
